# Anipose lib

 [![License](https://img.shields.io/badge/License-BSD%202--Clause-orange.svg)](https://opensource.org/licenses/BSD-2-Clause)
 
An easy-to-use library for calibrating cameras and triangulation in Python.

This is the backend library for the [Anipose](https://github.com/lambdaloop/anipose) package.

The [documentation](https://anipose.readthedocs.io/en/latest/aniposelib-tutorial.html) is located in Anipose repository.

